@@ -65,24 +65,23 @@ class Client(object):
         kwargs.setdefault('user_agent', 'python-congressclient')
         self.httpclient = adapter.LegacyJsonAdapter(**kwargs)
 
-    def create_policy(self, body):
-        resp, body = self.httpclient.post(
-            self.policies, body=body)
+    def create_policy(self, body, library_policy_id=None):
+        url = self.policies
+        if library_policy_id:
+            url = url + "?library_policy=%s" % library_policy_id
+        resp, body = self.httpclient.post(url, body=body)
         return body
 
     def delete_policy(self, policy):
-        resp, body = self.httpclient.delete(
-            self.policy_path % policy)
+        resp, body = self.httpclient.delete(self.policy_path % policy)
         return body
 
     def show_policy(self, policy):
-        resp, body = self.httpclient.get(
-            self.policy_path % policy)
+        resp, body = self.httpclient.get(self.policy_path % policy)
         return body
 
     def create_library_policy(self, body):
-        resp, body = self.httpclient.post(
-            self.library_policies, body=body)
+        resp, body = self.httpclient.post(self.library_policies, body=body)
         return body
 
     def delete_library_policy(self, policy):
@@ -90,9 +89,10 @@ class Client(object):
             self.library_policy_path % policy)
         return body
 
-    def show_library_policy(self, policy):
+    def show_library_policy(self, policy, include_rules=True):
+        query = "?include_rules=%s" % include_rules
         resp, body = self.httpclient.get(
-            self.library_policy_path % policy)
+            (self.library_policy_path % policy) + query)
         return body
 
     def create_policy_rule(self, policy_name, body=None):
@@ -126,8 +126,9 @@ class Client(object):
         resp, body = self.httpclient.get(self.policies)
         return body
 
-    def list_library_policy(self):
-        resp, body = self.httpclient.get(self.library_policies)
+    def list_library_policy(self, include_rules=True):
+        query = "?include_rules=%s" % include_rules
+        resp, body = self.httpclient.get(self.library_policies + query)
         return body
 
     def list_policy_tables(self, policy_name):
